@@ -1,6 +1,7 @@
 """Unit-tests for the configclass module."""
 
 import dataclasses
+from typing import Optional
 
 import pytest
 
@@ -9,9 +10,48 @@ from cfgclasses import (
     mutually_exclusive,
     parse_args,
     parse_args_with_submodes,
+    parse_known_args,
+    parse_known_args_with_submodes,
     validator,
 )
 
+def test_type_handling() -> None:
+    """Test the use of various basic types."""
+    @dataclasses.dataclass
+    class TestConfig:
+        """Config for the type handling tests."""
+
+        anum: int = arg("A simple integer field")
+        afloat: float = arg("A simple float field")
+        astring: str = arg("A simple string field")
+        abool: bool = arg("A simple boolean field")
+        anum_list: list[int] = arg("A simple list of integers field")
+        astring_list: list[str] = arg("A simple list of strings field")
+
+    assert parse_args(TestConfig, [
+        "--anum",
+        "1",
+        "--afloat",
+        "1.0",
+        "--astring",
+        "test",
+        "--abool",
+        "--anum-list",
+        "1",
+        "2",
+        "3",
+        "--astring-list",
+        "test",
+        "test2",
+    ]) == TestConfig(
+        anum=1,
+        afloat=1.0,
+        astring="test",
+        abool=True,
+        anum_list=[1, 2, 3],
+        astring_list=["test", "test2"],
+    )
+
 
 def test_mutually_exclusive() -> None:
     """Test the use of mutually exclusive groups."""
@@ -95,6 +135,49 @@ def test_submodes() -> None:
         )
 
 
+def test_unknown_args() -> None:
+    """Test the handling of unknown arguments both with and without submodes."""
+
+    @dataclasses.dataclass
+    class TopLevelConfig:
+        """Top level config class containing the submodes."""
+
+        debug: bool = arg("Enable debug mode")
+
+    # Check the unknown args handling without submodes
+    assert parse_known_args(
+        TopLevelConfig, ["--debug", "--unknown", "arg"]
+    ) == (TopLevelConfig(debug=True), ["--unknown", "arg"])
+
+    @dataclasses.dataclass
+    class SubmodeA:
+        """Config for the submode A."""
+
+        anum: int = arg("A simple integer field")
+
+    @dataclasses.dataclass
+    class SubmodeB:
+        """Config for the submode B."""
+
+        bnum: int = arg("A simple integer field")
+
+    submodes = {
+        "a": SubmodeA,
+        "b": SubmodeB,
+    }
+
+    # Check the same but with submodes enabled
+    assert parse_known_args_with_submodes(
+        TopLevelConfig,
+        ["--debug", "a", "--anum", "10000", "--unknown", "arg"],
+        submodes,
+    ) == (
+        TopLevelConfig(debug=True),
+        SubmodeA(anum=10000),
+        ["--unknown", "arg"],
+    )
+
+
 def test_validation_simple() -> None:
     """Test the use of validation functions."""
 
